@@ -159,8 +159,8 @@ void SddmKcm::synchronizeSettings()
     // read Plasma values
     KConfig cursorConfig(QStringLiteral("kcminputrc"));
     KConfigGroup cursorConfigGroup(&cursorConfig, "Mouse");
-    QVariant cursorTheme = cursorConfigGroup.readEntry("cursorTheme", QString());
-    QVariant cursorSize = cursorConfigGroup.readEntry("cursorSize", QString());
+    QString cursorTheme = cursorConfigGroup.readEntry("cursorTheme", QString());
+    QString cursorSize = cursorConfigGroup.readEntry("cursorSize", QString());
 
     KConfig dpiConfig(QStringLiteral("kcmfonts"));
     KConfigGroup dpiConfigGroup(&dpiConfig, "General");
@@ -181,6 +181,7 @@ void SddmKcm::synchronizeSettings()
     const QString kdeglobalsPath = QStandardPaths::locate(QStandardPaths::GenericConfigLocation, QStringLiteral("kdeglobals"));
     const QString plasmarcPath = QStandardPaths::locate(QStandardPaths::GenericConfigLocation, QStringLiteral("plasmarc"));
     const QString kcminputrcPath = QStandardPaths::locate(QStandardPaths::GenericConfigLocation, QStringLiteral("kcminputrc"));
+    const QString kwinoutputconfigPath = QStandardPaths::locate(QStandardPaths::GenericConfigLocation, QStringLiteral("kwinoutputconfig.json"));
 
     // send values and paths to helper, debug if it fails
     QVariantMap args;
@@ -192,12 +193,14 @@ void SddmKcm::synchronizeSettings()
     if (!cursorTheme.isNull()) {
         args[QStringLiteral("kde_settings.conf/Theme/CursorTheme")] = cursorTheme;
     } else {
-        qDebug() << "Cannot find cursor theme value.";
+        qDebug() << "Cannot find cursor theme value; unsetting it";
+        args[QStringLiteral("kde_settings.conf/Theme/CursorTheme")] = QVariant();
     }
     if (!cursorSize.isNull()) {
         args[QStringLiteral("kde_settings.conf/Theme/CursorSize")] = cursorSize;
     } else {
-        qDebug() << "Cannot find cursor size value.";
+        qDebug() << "Cannot find cursor size value; unsetting it";
+        args[QStringLiteral("kde_settings.conf/Theme/CursorSize")] = QVariant();
     }
 
     if (!dpiValue.isEmpty()) {
@@ -248,6 +251,12 @@ void SddmKcm::synchronizeSettings()
         qDebug() << "Cannot find kcminputrc file.";
     }
 
+    if (!kwinoutputconfigPath.isEmpty()) {
+        args[QStringLiteral("kwinoutputconfig")] = kwinoutputconfigPath;
+    } else {
+        qDebug() << "Cannot find kwinoutputconfiguration.json file";
+    }
+
     auto path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "kscreen/", QStandardPaths::LocateDirectory);
     if (!path.isEmpty()) {
         args[QStringLiteral("kscreen-config")] = path;
